# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetIdpEnvironmentResult',
    'AwaitableGetIdpEnvironmentResult',
    'get_idp_environment',
    'get_idp_environment_output',
]

@pulumi.output_type
class GetIdpEnvironmentResult:
    """
    A collection of values returned by getIdpEnvironment.
    """
    def __init__(__self__, based_on=None, blueprint_identifier=None, blueprint_version=None, id=None, identifier=None, inputs=None, name=None, org_id=None, overrides=None, owner=None, project_id=None, target_state=None):
        if based_on and not isinstance(based_on, str):
            raise TypeError("Expected argument 'based_on' to be a str")
        pulumi.set(__self__, "based_on", based_on)
        if blueprint_identifier and not isinstance(blueprint_identifier, str):
            raise TypeError("Expected argument 'blueprint_identifier' to be a str")
        pulumi.set(__self__, "blueprint_identifier", blueprint_identifier)
        if blueprint_version and not isinstance(blueprint_version, str):
            raise TypeError("Expected argument 'blueprint_version' to be a str")
        pulumi.set(__self__, "blueprint_version", blueprint_version)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if inputs and not isinstance(inputs, str):
            raise TypeError("Expected argument 'inputs' to be a str")
        pulumi.set(__self__, "inputs", inputs)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if overrides and not isinstance(overrides, str):
            raise TypeError("Expected argument 'overrides' to be a str")
        pulumi.set(__self__, "overrides", overrides)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if target_state and not isinstance(target_state, str):
            raise TypeError("Expected argument 'target_state' to be a str")
        pulumi.set(__self__, "target_state", target_state)

    @_builtins.property
    @pulumi.getter(name="basedOn")
    def based_on(self) -> _builtins.str:
        """
        Based on environment reference. This should be passed as \\n\\n.\\n\\n/\\n\\n
        """
        return pulumi.get(self, "based_on")

    @_builtins.property
    @pulumi.getter(name="blueprintIdentifier")
    def blueprint_identifier(self) -> _builtins.str:
        """
        Blueprint to base the environment on
        """
        return pulumi.get(self, "blueprint_identifier")

    @_builtins.property
    @pulumi.getter(name="blueprintVersion")
    def blueprint_version(self) -> _builtins.str:
        """
        Version of the blueprint to base the environment on
        """
        return pulumi.get(self, "blueprint_version")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def inputs(self) -> _builtins.str:
        """
        Additional inputs for controlling the environment. This should be passed as a map of key-value pairs in YAML format
        """
        return pulumi.get(self, "inputs")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> _builtins.str:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter
    def overrides(self) -> _builtins.str:
        """
        Overrides for environment blueprint inputs in YAML format
        """
        return pulumi.get(self, "overrides")

    @_builtins.property
    @pulumi.getter
    def owner(self) -> _builtins.str:
        """
        Owner of the environment
        """
        return pulumi.get(self, "owner")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="targetState")
    def target_state(self) -> _builtins.str:
        """
        target state of the environment. If different from the current, a pipeline will be triggered to update the environment
        """
        return pulumi.get(self, "target_state")


class AwaitableGetIdpEnvironmentResult(GetIdpEnvironmentResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIdpEnvironmentResult(
            based_on=self.based_on,
            blueprint_identifier=self.blueprint_identifier,
            blueprint_version=self.blueprint_version,
            id=self.id,
            identifier=self.identifier,
            inputs=self.inputs,
            name=self.name,
            org_id=self.org_id,
            overrides=self.overrides,
            owner=self.owner,
            project_id=self.project_id,
            target_state=self.target_state)


def get_idp_environment(identifier: Optional[_builtins.str] = None,
                        name: Optional[_builtins.str] = None,
                        org_id: Optional[_builtins.str] = None,
                        project_id: Optional[_builtins.str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIdpEnvironmentResult:
    """
    Data source for retrieving IDP environments.


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getIdpEnvironment:getIdpEnvironment', __args__, opts=opts, typ=GetIdpEnvironmentResult).value

    return AwaitableGetIdpEnvironmentResult(
        based_on=pulumi.get(__ret__, 'based_on'),
        blueprint_identifier=pulumi.get(__ret__, 'blueprint_identifier'),
        blueprint_version=pulumi.get(__ret__, 'blueprint_version'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        inputs=pulumi.get(__ret__, 'inputs'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        overrides=pulumi.get(__ret__, 'overrides'),
        owner=pulumi.get(__ret__, 'owner'),
        project_id=pulumi.get(__ret__, 'project_id'),
        target_state=pulumi.get(__ret__, 'target_state'))
def get_idp_environment_output(identifier: Optional[pulumi.Input[_builtins.str]] = None,
                               name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               org_id: Optional[pulumi.Input[_builtins.str]] = None,
                               project_id: Optional[pulumi.Input[_builtins.str]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetIdpEnvironmentResult]:
    """
    Data source for retrieving IDP environments.


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getIdpEnvironment:getIdpEnvironment', __args__, opts=opts, typ=GetIdpEnvironmentResult)
    return __ret__.apply(lambda __response__: GetIdpEnvironmentResult(
        based_on=pulumi.get(__response__, 'based_on'),
        blueprint_identifier=pulumi.get(__response__, 'blueprint_identifier'),
        blueprint_version=pulumi.get(__response__, 'blueprint_version'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        inputs=pulumi.get(__response__, 'inputs'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        overrides=pulumi.get(__response__, 'overrides'),
        owner=pulumi.get(__response__, 'owner'),
        project_id=pulumi.get(__response__, 'project_id'),
        target_state=pulumi.get(__response__, 'target_state')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['InfraVariableSetArgs', 'InfraVariableSet']

@pulumi.input_type
class InfraVariableSetArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 connectors: Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetConnectorArgs']]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetEnvironmentVariableArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 terraform_variable_files: Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetTerraformVariableFileArgs']]]] = None,
                 terraform_variables: Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetTerraformVariableArgs']]]] = None):
        """
        The set of arguments for constructing a InfraVariableSet resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[Sequence[pulumi.Input['InfraVariableSetConnectorArgs']]] connectors: Provider connectors configured on the Variable Set. Only one connector of a type is supported
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Sequence[pulumi.Input['InfraVariableSetEnvironmentVariableArgs']]] environment_variables: Environment variables configured on the Variable Set
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        pulumi.set(__self__, "identifier", identifier)
        if connectors is not None:
            pulumi.set(__self__, "connectors", connectors)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if environment_variables is not None:
            pulumi.set(__self__, "environment_variables", environment_variables)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if terraform_variable_files is not None:
            pulumi.set(__self__, "terraform_variable_files", terraform_variable_files)
        if terraform_variables is not None:
            pulumi.set(__self__, "terraform_variables", terraform_variables)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def connectors(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetConnectorArgs']]]]:
        """
        Provider connectors configured on the Variable Set. Only one connector of a type is supported
        """
        return pulumi.get(self, "connectors")

    @connectors.setter
    def connectors(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetConnectorArgs']]]]):
        pulumi.set(self, "connectors", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetEnvironmentVariableArgs']]]]:
        """
        Environment variables configured on the Variable Set
        """
        return pulumi.get(self, "environment_variables")

    @environment_variables.setter
    def environment_variables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetEnvironmentVariableArgs']]]]):
        pulumi.set(self, "environment_variables", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="terraformVariableFiles")
    def terraform_variable_files(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetTerraformVariableFileArgs']]]]:
        return pulumi.get(self, "terraform_variable_files")

    @terraform_variable_files.setter
    def terraform_variable_files(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetTerraformVariableFileArgs']]]]):
        pulumi.set(self, "terraform_variable_files", value)

    @_builtins.property
    @pulumi.getter(name="terraformVariables")
    def terraform_variables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetTerraformVariableArgs']]]]:
        return pulumi.get(self, "terraform_variables")

    @terraform_variables.setter
    def terraform_variables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetTerraformVariableArgs']]]]):
        pulumi.set(self, "terraform_variables", value)


@pulumi.input_type
class _InfraVariableSetState:
    def __init__(__self__, *,
                 connectors: Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetConnectorArgs']]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetEnvironmentVariableArgs']]]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 terraform_variable_files: Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetTerraformVariableFileArgs']]]] = None,
                 terraform_variables: Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetTerraformVariableArgs']]]] = None):
        """
        Input properties used for looking up and filtering InfraVariableSet resources.
        :param pulumi.Input[Sequence[pulumi.Input['InfraVariableSetConnectorArgs']]] connectors: Provider connectors configured on the Variable Set. Only one connector of a type is supported
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Sequence[pulumi.Input['InfraVariableSetEnvironmentVariableArgs']]] environment_variables: Environment variables configured on the Variable Set
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        if connectors is not None:
            pulumi.set(__self__, "connectors", connectors)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if environment_variables is not None:
            pulumi.set(__self__, "environment_variables", environment_variables)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if terraform_variable_files is not None:
            pulumi.set(__self__, "terraform_variable_files", terraform_variable_files)
        if terraform_variables is not None:
            pulumi.set(__self__, "terraform_variables", terraform_variables)

    @_builtins.property
    @pulumi.getter
    def connectors(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetConnectorArgs']]]]:
        """
        Provider connectors configured on the Variable Set. Only one connector of a type is supported
        """
        return pulumi.get(self, "connectors")

    @connectors.setter
    def connectors(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetConnectorArgs']]]]):
        pulumi.set(self, "connectors", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetEnvironmentVariableArgs']]]]:
        """
        Environment variables configured on the Variable Set
        """
        return pulumi.get(self, "environment_variables")

    @environment_variables.setter
    def environment_variables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetEnvironmentVariableArgs']]]]):
        pulumi.set(self, "environment_variables", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="terraformVariableFiles")
    def terraform_variable_files(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetTerraformVariableFileArgs']]]]:
        return pulumi.get(self, "terraform_variable_files")

    @terraform_variable_files.setter
    def terraform_variable_files(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetTerraformVariableFileArgs']]]]):
        pulumi.set(self, "terraform_variable_files", value)

    @_builtins.property
    @pulumi.getter(name="terraformVariables")
    def terraform_variables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetTerraformVariableArgs']]]]:
        return pulumi.get(self, "terraform_variables")

    @terraform_variables.setter
    def terraform_variables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InfraVariableSetTerraformVariableArgs']]]]):
        pulumi.set(self, "terraform_variables", value)


@pulumi.type_token("harness:platform/infraVariableSet:InfraVariableSet")
class InfraVariableSet(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connectors: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InfraVariableSetConnectorArgs', 'InfraVariableSetConnectorArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InfraVariableSetEnvironmentVariableArgs', 'InfraVariableSetEnvironmentVariableArgsDict']]]]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 terraform_variable_files: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InfraVariableSetTerraformVariableFileArgs', 'InfraVariableSetTerraformVariableFileArgsDict']]]]] = None,
                 terraform_variables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InfraVariableSetTerraformVariableArgs', 'InfraVariableSetTerraformVariableArgsDict']]]]] = None,
                 __props__=None):
        """
        Resource for managing Variable Sets

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.InfraVariableSet("example",
            identifier="example",
            name="example",
            org_id=test["id"],
            project_id=test_harness_platform_project["id"],
            description="some description",
            environment_variables=[
                {
                    "key": "key1",
                    "value": "value1",
                    "value_type": "string",
                },
                {
                    "key": "key2",
                    "value": "harness_platform_secret_text.test.id",
                    "value_type": "secret",
                },
            ],
            terraform_variables=[
                {
                    "key": "key1",
                    "value": "1111",
                    "value_type": "string",
                },
                {
                    "key": "key2",
                    "value": "1111u",
                    "value_type": "string",
                },
            ],
            terraform_variable_files=[
                {
                    "repository": "https://github.com/org/repo",
                    "repository_branch": "main",
                    "repository_path": "tf/aws/basic",
                    "repository_connector": "harness_platform_connector_github.test.id",
                },
                {
                    "repository": "https://github.com/org/repo",
                    "repository_branch": "br2",
                    "repository_path": "tf/aws/basic",
                    "repository_connector": "harness_platform_connector_github.test.id",
                },
            ],
            connectors=[
                {
                    "connector_ref": "harness_platform_connector_aws.test.id",
                    "type": "aws",
                },
                {
                    "connector_ref": "harness_platform_connector_azure.test.id",
                    "type": "azure",
                },
            ])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level variable set

        ```sh
        $ pulumi import harness:platform/infraVariableSet:InfraVariableSet example <variable_set_id>
        ```

        Import org level variable set

        ```sh
        $ pulumi import harness:platform/infraVariableSet:InfraVariableSet example <ord_id>/<variable_set_id>
        ```

        Import project level variable set

        ```sh
        $ pulumi import harness:platform/infraVariableSet:InfraVariableSet example <org_id>/<project_id>/<variable_set_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['InfraVariableSetConnectorArgs', 'InfraVariableSetConnectorArgsDict']]]] connectors: Provider connectors configured on the Variable Set. Only one connector of a type is supported
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['InfraVariableSetEnvironmentVariableArgs', 'InfraVariableSetEnvironmentVariableArgsDict']]]] environment_variables: Environment variables configured on the Variable Set
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InfraVariableSetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for managing Variable Sets

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.InfraVariableSet("example",
            identifier="example",
            name="example",
            org_id=test["id"],
            project_id=test_harness_platform_project["id"],
            description="some description",
            environment_variables=[
                {
                    "key": "key1",
                    "value": "value1",
                    "value_type": "string",
                },
                {
                    "key": "key2",
                    "value": "harness_platform_secret_text.test.id",
                    "value_type": "secret",
                },
            ],
            terraform_variables=[
                {
                    "key": "key1",
                    "value": "1111",
                    "value_type": "string",
                },
                {
                    "key": "key2",
                    "value": "1111u",
                    "value_type": "string",
                },
            ],
            terraform_variable_files=[
                {
                    "repository": "https://github.com/org/repo",
                    "repository_branch": "main",
                    "repository_path": "tf/aws/basic",
                    "repository_connector": "harness_platform_connector_github.test.id",
                },
                {
                    "repository": "https://github.com/org/repo",
                    "repository_branch": "br2",
                    "repository_path": "tf/aws/basic",
                    "repository_connector": "harness_platform_connector_github.test.id",
                },
            ],
            connectors=[
                {
                    "connector_ref": "harness_platform_connector_aws.test.id",
                    "type": "aws",
                },
                {
                    "connector_ref": "harness_platform_connector_azure.test.id",
                    "type": "azure",
                },
            ])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level variable set

        ```sh
        $ pulumi import harness:platform/infraVariableSet:InfraVariableSet example <variable_set_id>
        ```

        Import org level variable set

        ```sh
        $ pulumi import harness:platform/infraVariableSet:InfraVariableSet example <ord_id>/<variable_set_id>
        ```

        Import project level variable set

        ```sh
        $ pulumi import harness:platform/infraVariableSet:InfraVariableSet example <org_id>/<project_id>/<variable_set_id>
        ```

        :param str resource_name: The name of the resource.
        :param InfraVariableSetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InfraVariableSetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connectors: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InfraVariableSetConnectorArgs', 'InfraVariableSetConnectorArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InfraVariableSetEnvironmentVariableArgs', 'InfraVariableSetEnvironmentVariableArgsDict']]]]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 terraform_variable_files: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InfraVariableSetTerraformVariableFileArgs', 'InfraVariableSetTerraformVariableFileArgsDict']]]]] = None,
                 terraform_variables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InfraVariableSetTerraformVariableArgs', 'InfraVariableSetTerraformVariableArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InfraVariableSetArgs.__new__(InfraVariableSetArgs)

            __props__.__dict__["connectors"] = connectors
            __props__.__dict__["description"] = description
            __props__.__dict__["environment_variables"] = environment_variables
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["name"] = name
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["tags"] = tags
            __props__.__dict__["terraform_variable_files"] = terraform_variable_files
            __props__.__dict__["terraform_variables"] = terraform_variables
        super(InfraVariableSet, __self__).__init__(
            'harness:platform/infraVariableSet:InfraVariableSet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            connectors: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InfraVariableSetConnectorArgs', 'InfraVariableSetConnectorArgsDict']]]]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            environment_variables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InfraVariableSetEnvironmentVariableArgs', 'InfraVariableSetEnvironmentVariableArgsDict']]]]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            terraform_variable_files: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InfraVariableSetTerraformVariableFileArgs', 'InfraVariableSetTerraformVariableFileArgsDict']]]]] = None,
            terraform_variables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InfraVariableSetTerraformVariableArgs', 'InfraVariableSetTerraformVariableArgsDict']]]]] = None) -> 'InfraVariableSet':
        """
        Get an existing InfraVariableSet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['InfraVariableSetConnectorArgs', 'InfraVariableSetConnectorArgsDict']]]] connectors: Provider connectors configured on the Variable Set. Only one connector of a type is supported
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['InfraVariableSetEnvironmentVariableArgs', 'InfraVariableSetEnvironmentVariableArgsDict']]]] environment_variables: Environment variables configured on the Variable Set
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InfraVariableSetState.__new__(_InfraVariableSetState)

        __props__.__dict__["connectors"] = connectors
        __props__.__dict__["description"] = description
        __props__.__dict__["environment_variables"] = environment_variables
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["terraform_variable_files"] = terraform_variable_files
        __props__.__dict__["terraform_variables"] = terraform_variables
        return InfraVariableSet(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def connectors(self) -> pulumi.Output[Optional[Sequence['outputs.InfraVariableSetConnector']]]:
        """
        Provider connectors configured on the Variable Set. Only one connector of a type is supported
        """
        return pulumi.get(self, "connectors")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> pulumi.Output[Optional[Sequence['outputs.InfraVariableSetEnvironmentVariable']]]:
        """
        Environment variables configured on the Variable Set
        """
        return pulumi.get(self, "environment_variables")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="terraformVariableFiles")
    def terraform_variable_files(self) -> pulumi.Output[Optional[Sequence['outputs.InfraVariableSetTerraformVariableFile']]]:
        return pulumi.get(self, "terraform_variable_files")

    @_builtins.property
    @pulumi.getter(name="terraformVariables")
    def terraform_variables(self) -> pulumi.Output[Optional[Sequence['outputs.InfraVariableSetTerraformVariable']]]:
        return pulumi.get(self, "terraform_variables")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['HubArgs', 'Hub']

@pulumi.input_type
class HubArgs:
    def __init__(__self__, *,
                 connector_id: pulumi.Input[_builtins.str],
                 repo_branch: pulumi.Input[_builtins.str],
                 connector_scope: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a Hub resource.
        :param pulumi.Input[_builtins.str] connector_id: ID of the Git connector
        :param pulumi.Input[_builtins.str] repo_branch: Git repository branch
        :param pulumi.Input[_builtins.str] connector_scope: Scope of the Git connector (PROJECT, ORGANISATION, or ACCOUNT)
        :param pulumi.Input[_builtins.str] description: Description of the chaos hub
        :param pulumi.Input[_builtins.bool] is_default: Whether this is the default chaos hub
        :param pulumi.Input[_builtins.str] name: Name of the chaos hub
        :param pulumi.Input[_builtins.str] org_id: The organization ID of the chaos hub
        :param pulumi.Input[_builtins.str] project_id: The project ID of the chaos hub
        :param pulumi.Input[_builtins.str] repo_name: Name of the Git repository (required for account-level connectors)
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the chaos hub
        """
        pulumi.set(__self__, "connector_id", connector_id)
        pulumi.set(__self__, "repo_branch", repo_branch)
        if connector_scope is not None:
            pulumi.set(__self__, "connector_scope", connector_scope)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if repo_name is not None:
            pulumi.set(__self__, "repo_name", repo_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="connectorId")
    def connector_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the Git connector
        """
        return pulumi.get(self, "connector_id")

    @connector_id.setter
    def connector_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "connector_id", value)

    @_builtins.property
    @pulumi.getter(name="repoBranch")
    def repo_branch(self) -> pulumi.Input[_builtins.str]:
        """
        Git repository branch
        """
        return pulumi.get(self, "repo_branch")

    @repo_branch.setter
    def repo_branch(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "repo_branch", value)

    @_builtins.property
    @pulumi.getter(name="connectorScope")
    def connector_scope(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Scope of the Git connector (PROJECT, ORGANISATION, or ACCOUNT)
        """
        return pulumi.get(self, "connector_scope")

    @connector_scope.setter
    def connector_scope(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "connector_scope", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the chaos hub
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether this is the default chaos hub
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_default", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the chaos hub
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The organization ID of the chaos hub
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The project ID of the chaos hub
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="repoName")
    def repo_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Git repository (required for account-level connectors)
        """
        return pulumi.get(self, "repo_name")

    @repo_name.setter
    def repo_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repo_name", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the chaos hub
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _HubState:
    def __init__(__self__, *,
                 connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                 connector_scope: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 is_available: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 last_synced_at: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 total_experiments: Optional[pulumi.Input[_builtins.int]] = None,
                 total_faults: Optional[pulumi.Input[_builtins.int]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Hub resources.
        :param pulumi.Input[_builtins.str] connector_id: ID of the Git connector
        :param pulumi.Input[_builtins.str] connector_scope: Scope of the Git connector (PROJECT, ORGANISATION, or ACCOUNT)
        :param pulumi.Input[_builtins.str] created_at: Creation timestamp
        :param pulumi.Input[_builtins.str] description: Description of the chaos hub
        :param pulumi.Input[_builtins.bool] is_available: Whether the chaos hub is available
        :param pulumi.Input[_builtins.bool] is_default: Whether this is the default chaos hub
        :param pulumi.Input[_builtins.str] last_synced_at: Timestamp of the last sync
        :param pulumi.Input[_builtins.str] name: Name of the chaos hub
        :param pulumi.Input[_builtins.str] org_id: The organization ID of the chaos hub
        :param pulumi.Input[_builtins.str] project_id: The project ID of the chaos hub
        :param pulumi.Input[_builtins.str] repo_branch: Git repository branch
        :param pulumi.Input[_builtins.str] repo_name: Name of the Git repository (required for account-level connectors)
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the chaos hub
        :param pulumi.Input[_builtins.int] total_experiments: Total number of experiments in the hub
        :param pulumi.Input[_builtins.int] total_faults: Total number of faults in the hub
        :param pulumi.Input[_builtins.str] updated_at: Last update timestamp
        """
        if connector_id is not None:
            pulumi.set(__self__, "connector_id", connector_id)
        if connector_scope is not None:
            pulumi.set(__self__, "connector_scope", connector_scope)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if is_available is not None:
            pulumi.set(__self__, "is_available", is_available)
        if is_default is not None:
            pulumi.set(__self__, "is_default", is_default)
        if last_synced_at is not None:
            pulumi.set(__self__, "last_synced_at", last_synced_at)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if repo_branch is not None:
            pulumi.set(__self__, "repo_branch", repo_branch)
        if repo_name is not None:
            pulumi.set(__self__, "repo_name", repo_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if total_experiments is not None:
            pulumi.set(__self__, "total_experiments", total_experiments)
        if total_faults is not None:
            pulumi.set(__self__, "total_faults", total_faults)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="connectorId")
    def connector_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the Git connector
        """
        return pulumi.get(self, "connector_id")

    @connector_id.setter
    def connector_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "connector_id", value)

    @_builtins.property
    @pulumi.getter(name="connectorScope")
    def connector_scope(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Scope of the Git connector (PROJECT, ORGANISATION, or ACCOUNT)
        """
        return pulumi.get(self, "connector_scope")

    @connector_scope.setter
    def connector_scope(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "connector_scope", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Creation timestamp
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the chaos hub
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="isAvailable")
    def is_available(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the chaos hub is available
        """
        return pulumi.get(self, "is_available")

    @is_available.setter
    def is_available(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_available", value)

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether this is the default chaos hub
        """
        return pulumi.get(self, "is_default")

    @is_default.setter
    def is_default(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_default", value)

    @_builtins.property
    @pulumi.getter(name="lastSyncedAt")
    def last_synced_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Timestamp of the last sync
        """
        return pulumi.get(self, "last_synced_at")

    @last_synced_at.setter
    def last_synced_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_synced_at", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the chaos hub
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The organization ID of the chaos hub
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The project ID of the chaos hub
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="repoBranch")
    def repo_branch(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Git repository branch
        """
        return pulumi.get(self, "repo_branch")

    @repo_branch.setter
    def repo_branch(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repo_branch", value)

    @_builtins.property
    @pulumi.getter(name="repoName")
    def repo_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Git repository (required for account-level connectors)
        """
        return pulumi.get(self, "repo_name")

    @repo_name.setter
    def repo_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repo_name", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the chaos hub
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="totalExperiments")
    def total_experiments(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Total number of experiments in the hub
        """
        return pulumi.get(self, "total_experiments")

    @total_experiments.setter
    def total_experiments(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "total_experiments", value)

    @_builtins.property
    @pulumi.getter(name="totalFaults")
    def total_faults(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Total number of faults in the hub
        """
        return pulumi.get(self, "total_faults")

    @total_faults.setter
    def total_faults(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "total_faults", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Last update timestamp
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.type_token("harness:chaos/hub:Hub")
class Hub(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                 connector_scope: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Resource for managing a Harness Chaos Hub

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.chaos.Hub("example",
            org_id="<org_id>",
            project_id="<project_id>",
            name="<name>",
            description="<description>",
            connector_id="<connector_id>",
            repo_branch="<repo_branch>",
            repo_name="<repo_name>",
            is_default=False,
            tags=[
                "<tag1>",
                "<tag2>",
            ])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import Project level Chaos Hub

        ```sh
        $ pulumi import harness:chaos/hub:Hub example <org_id>/<project_id>/<hub_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] connector_id: ID of the Git connector
        :param pulumi.Input[_builtins.str] connector_scope: Scope of the Git connector (PROJECT, ORGANISATION, or ACCOUNT)
        :param pulumi.Input[_builtins.str] description: Description of the chaos hub
        :param pulumi.Input[_builtins.bool] is_default: Whether this is the default chaos hub
        :param pulumi.Input[_builtins.str] name: Name of the chaos hub
        :param pulumi.Input[_builtins.str] org_id: The organization ID of the chaos hub
        :param pulumi.Input[_builtins.str] project_id: The project ID of the chaos hub
        :param pulumi.Input[_builtins.str] repo_branch: Git repository branch
        :param pulumi.Input[_builtins.str] repo_name: Name of the Git repository (required for account-level connectors)
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the chaos hub
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: HubArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for managing a Harness Chaos Hub

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.chaos.Hub("example",
            org_id="<org_id>",
            project_id="<project_id>",
            name="<name>",
            description="<description>",
            connector_id="<connector_id>",
            repo_branch="<repo_branch>",
            repo_name="<repo_name>",
            is_default=False,
            tags=[
                "<tag1>",
                "<tag2>",
            ])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import Project level Chaos Hub

        ```sh
        $ pulumi import harness:chaos/hub:Hub example <org_id>/<project_id>/<hub_id>
        ```

        :param str resource_name: The name of the resource.
        :param HubArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(HubArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 connector_id: Optional[pulumi.Input[_builtins.str]] = None,
                 connector_scope: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 is_default: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = HubArgs.__new__(HubArgs)

            if connector_id is None and not opts.urn:
                raise TypeError("Missing required property 'connector_id'")
            __props__.__dict__["connector_id"] = connector_id
            __props__.__dict__["connector_scope"] = connector_scope
            __props__.__dict__["description"] = description
            __props__.__dict__["is_default"] = is_default
            __props__.__dict__["name"] = name
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            if repo_branch is None and not opts.urn:
                raise TypeError("Missing required property 'repo_branch'")
            __props__.__dict__["repo_branch"] = repo_branch
            __props__.__dict__["repo_name"] = repo_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["created_at"] = None
            __props__.__dict__["is_available"] = None
            __props__.__dict__["last_synced_at"] = None
            __props__.__dict__["total_experiments"] = None
            __props__.__dict__["total_faults"] = None
            __props__.__dict__["updated_at"] = None
        super(Hub, __self__).__init__(
            'harness:chaos/hub:Hub',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            connector_id: Optional[pulumi.Input[_builtins.str]] = None,
            connector_scope: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            is_available: Optional[pulumi.Input[_builtins.bool]] = None,
            is_default: Optional[pulumi.Input[_builtins.bool]] = None,
            last_synced_at: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            repo_branch: Optional[pulumi.Input[_builtins.str]] = None,
            repo_name: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            total_experiments: Optional[pulumi.Input[_builtins.int]] = None,
            total_faults: Optional[pulumi.Input[_builtins.int]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None) -> 'Hub':
        """
        Get an existing Hub resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] connector_id: ID of the Git connector
        :param pulumi.Input[_builtins.str] connector_scope: Scope of the Git connector (PROJECT, ORGANISATION, or ACCOUNT)
        :param pulumi.Input[_builtins.str] created_at: Creation timestamp
        :param pulumi.Input[_builtins.str] description: Description of the chaos hub
        :param pulumi.Input[_builtins.bool] is_available: Whether the chaos hub is available
        :param pulumi.Input[_builtins.bool] is_default: Whether this is the default chaos hub
        :param pulumi.Input[_builtins.str] last_synced_at: Timestamp of the last sync
        :param pulumi.Input[_builtins.str] name: Name of the chaos hub
        :param pulumi.Input[_builtins.str] org_id: The organization ID of the chaos hub
        :param pulumi.Input[_builtins.str] project_id: The project ID of the chaos hub
        :param pulumi.Input[_builtins.str] repo_branch: Git repository branch
        :param pulumi.Input[_builtins.str] repo_name: Name of the Git repository (required for account-level connectors)
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the chaos hub
        :param pulumi.Input[_builtins.int] total_experiments: Total number of experiments in the hub
        :param pulumi.Input[_builtins.int] total_faults: Total number of faults in the hub
        :param pulumi.Input[_builtins.str] updated_at: Last update timestamp
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _HubState.__new__(_HubState)

        __props__.__dict__["connector_id"] = connector_id
        __props__.__dict__["connector_scope"] = connector_scope
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["is_available"] = is_available
        __props__.__dict__["is_default"] = is_default
        __props__.__dict__["last_synced_at"] = last_synced_at
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["repo_branch"] = repo_branch
        __props__.__dict__["repo_name"] = repo_name
        __props__.__dict__["tags"] = tags
        __props__.__dict__["total_experiments"] = total_experiments
        __props__.__dict__["total_faults"] = total_faults
        __props__.__dict__["updated_at"] = updated_at
        return Hub(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="connectorId")
    def connector_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the Git connector
        """
        return pulumi.get(self, "connector_id")

    @_builtins.property
    @pulumi.getter(name="connectorScope")
    def connector_scope(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Scope of the Git connector (PROJECT, ORGANISATION, or ACCOUNT)
        """
        return pulumi.get(self, "connector_scope")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        Creation timestamp
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the chaos hub
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="isAvailable")
    def is_available(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the chaos hub is available
        """
        return pulumi.get(self, "is_available")

    @_builtins.property
    @pulumi.getter(name="isDefault")
    def is_default(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether this is the default chaos hub
        """
        return pulumi.get(self, "is_default")

    @_builtins.property
    @pulumi.getter(name="lastSyncedAt")
    def last_synced_at(self) -> pulumi.Output[_builtins.str]:
        """
        Timestamp of the last sync
        """
        return pulumi.get(self, "last_synced_at")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the chaos hub
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The organization ID of the chaos hub
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The project ID of the chaos hub
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="repoBranch")
    def repo_branch(self) -> pulumi.Output[_builtins.str]:
        """
        Git repository branch
        """
        return pulumi.get(self, "repo_branch")

    @_builtins.property
    @pulumi.getter(name="repoName")
    def repo_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Name of the Git repository (required for account-level connectors)
        """
        return pulumi.get(self, "repo_name")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the chaos hub
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="totalExperiments")
    def total_experiments(self) -> pulumi.Output[_builtins.int]:
        """
        Total number of experiments in the hub
        """
        return pulumi.get(self, "total_experiments")

    @_builtins.property
    @pulumi.getter(name="totalFaults")
    def total_faults(self) -> pulumi.Output[_builtins.int]:
        """
        Total number of faults in the hub
        """
        return pulumi.get(self, "total_faults")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        Last update timestamp
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AwsArgs', 'Aws']

@pulumi.input_type
class AwsArgs:
    def __init__(__self__, *,
                 access_key_id: Optional[pulumi.Input[_builtins.str]] = None,
                 access_key_id_secret_name: Optional[pulumi.Input[_builtins.str]] = None,
                 assume_cross_account_role: Optional[pulumi.Input['AwsAssumeCrossAccountRoleArgs']] = None,
                 delegate_selector: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_access_key_secret_name: Optional[pulumi.Input[_builtins.str]] = None,
                 usage_scopes: Optional[pulumi.Input[Sequence[pulumi.Input['AwsUsageScopeArgs']]]] = None,
                 use_ec2_iam_credentials: Optional[pulumi.Input[_builtins.bool]] = None,
                 use_irsa: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a Aws resource.
        :param pulumi.Input[_builtins.str] access_key_id: The plain text AWS access key id.
        :param pulumi.Input[_builtins.str] access_key_id_secret_name: The name of the Harness secret containing the AWS access key id
        :param pulumi.Input['AwsAssumeCrossAccountRoleArgs'] assume_cross_account_role: Configuration for assuming a cross account role.
        :param pulumi.Input[_builtins.str] delegate_selector: Select the Delegate to use via one of its Selectors.
        :param pulumi.Input[_builtins.str] name: The name of the cloud provider.
        :param pulumi.Input[_builtins.str] secret_access_key_secret_name: The name of the Harness secret containing the AWS secret access key.
        :param pulumi.Input[Sequence[pulumi.Input['AwsUsageScopeArgs']]] usage_scopes: This block is used for scoping the resource to a specific set of applications or environments.
        :param pulumi.Input[_builtins.bool] use_ec2_iam_credentials: Use the EC2 Instance Profile for Service Accounts.
        :param pulumi.Input[_builtins.bool] use_irsa: Use the AWS IAM Role for Service Accounts.
        """
        if access_key_id is not None:
            pulumi.set(__self__, "access_key_id", access_key_id)
        if access_key_id_secret_name is not None:
            pulumi.set(__self__, "access_key_id_secret_name", access_key_id_secret_name)
        if assume_cross_account_role is not None:
            pulumi.set(__self__, "assume_cross_account_role", assume_cross_account_role)
        if delegate_selector is not None:
            pulumi.set(__self__, "delegate_selector", delegate_selector)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if secret_access_key_secret_name is not None:
            pulumi.set(__self__, "secret_access_key_secret_name", secret_access_key_secret_name)
        if usage_scopes is not None:
            pulumi.set(__self__, "usage_scopes", usage_scopes)
        if use_ec2_iam_credentials is not None:
            pulumi.set(__self__, "use_ec2_iam_credentials", use_ec2_iam_credentials)
        if use_irsa is not None:
            pulumi.set(__self__, "use_irsa", use_irsa)

    @_builtins.property
    @pulumi.getter(name="accessKeyId")
    def access_key_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The plain text AWS access key id.
        """
        return pulumi.get(self, "access_key_id")

    @access_key_id.setter
    def access_key_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_key_id", value)

    @_builtins.property
    @pulumi.getter(name="accessKeyIdSecretName")
    def access_key_id_secret_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Harness secret containing the AWS access key id
        """
        return pulumi.get(self, "access_key_id_secret_name")

    @access_key_id_secret_name.setter
    def access_key_id_secret_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_key_id_secret_name", value)

    @_builtins.property
    @pulumi.getter(name="assumeCrossAccountRole")
    def assume_cross_account_role(self) -> Optional[pulumi.Input['AwsAssumeCrossAccountRoleArgs']]:
        """
        Configuration for assuming a cross account role.
        """
        return pulumi.get(self, "assume_cross_account_role")

    @assume_cross_account_role.setter
    def assume_cross_account_role(self, value: Optional[pulumi.Input['AwsAssumeCrossAccountRoleArgs']]):
        pulumi.set(self, "assume_cross_account_role", value)

    @_builtins.property
    @pulumi.getter(name="delegateSelector")
    def delegate_selector(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Select the Delegate to use via one of its Selectors.
        """
        return pulumi.get(self, "delegate_selector")

    @delegate_selector.setter
    def delegate_selector(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "delegate_selector", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the cloud provider.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="secretAccessKeySecretName")
    def secret_access_key_secret_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Harness secret containing the AWS secret access key.
        """
        return pulumi.get(self, "secret_access_key_secret_name")

    @secret_access_key_secret_name.setter
    def secret_access_key_secret_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_access_key_secret_name", value)

    @_builtins.property
    @pulumi.getter(name="usageScopes")
    def usage_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AwsUsageScopeArgs']]]]:
        """
        This block is used for scoping the resource to a specific set of applications or environments.
        """
        return pulumi.get(self, "usage_scopes")

    @usage_scopes.setter
    def usage_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AwsUsageScopeArgs']]]]):
        pulumi.set(self, "usage_scopes", value)

    @_builtins.property
    @pulumi.getter(name="useEc2IamCredentials")
    def use_ec2_iam_credentials(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Use the EC2 Instance Profile for Service Accounts.
        """
        return pulumi.get(self, "use_ec2_iam_credentials")

    @use_ec2_iam_credentials.setter
    def use_ec2_iam_credentials(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "use_ec2_iam_credentials", value)

    @_builtins.property
    @pulumi.getter(name="useIrsa")
    def use_irsa(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Use the AWS IAM Role for Service Accounts.
        """
        return pulumi.get(self, "use_irsa")

    @use_irsa.setter
    def use_irsa(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "use_irsa", value)


@pulumi.input_type
class _AwsState:
    def __init__(__self__, *,
                 access_key_id: Optional[pulumi.Input[_builtins.str]] = None,
                 access_key_id_secret_name: Optional[pulumi.Input[_builtins.str]] = None,
                 assume_cross_account_role: Optional[pulumi.Input['AwsAssumeCrossAccountRoleArgs']] = None,
                 delegate_selector: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_access_key_secret_name: Optional[pulumi.Input[_builtins.str]] = None,
                 usage_scopes: Optional[pulumi.Input[Sequence[pulumi.Input['AwsUsageScopeArgs']]]] = None,
                 use_ec2_iam_credentials: Optional[pulumi.Input[_builtins.bool]] = None,
                 use_irsa: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering Aws resources.
        :param pulumi.Input[_builtins.str] access_key_id: The plain text AWS access key id.
        :param pulumi.Input[_builtins.str] access_key_id_secret_name: The name of the Harness secret containing the AWS access key id
        :param pulumi.Input['AwsAssumeCrossAccountRoleArgs'] assume_cross_account_role: Configuration for assuming a cross account role.
        :param pulumi.Input[_builtins.str] delegate_selector: Select the Delegate to use via one of its Selectors.
        :param pulumi.Input[_builtins.str] name: The name of the cloud provider.
        :param pulumi.Input[_builtins.str] secret_access_key_secret_name: The name of the Harness secret containing the AWS secret access key.
        :param pulumi.Input[Sequence[pulumi.Input['AwsUsageScopeArgs']]] usage_scopes: This block is used for scoping the resource to a specific set of applications or environments.
        :param pulumi.Input[_builtins.bool] use_ec2_iam_credentials: Use the EC2 Instance Profile for Service Accounts.
        :param pulumi.Input[_builtins.bool] use_irsa: Use the AWS IAM Role for Service Accounts.
        """
        if access_key_id is not None:
            pulumi.set(__self__, "access_key_id", access_key_id)
        if access_key_id_secret_name is not None:
            pulumi.set(__self__, "access_key_id_secret_name", access_key_id_secret_name)
        if assume_cross_account_role is not None:
            pulumi.set(__self__, "assume_cross_account_role", assume_cross_account_role)
        if delegate_selector is not None:
            pulumi.set(__self__, "delegate_selector", delegate_selector)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if secret_access_key_secret_name is not None:
            pulumi.set(__self__, "secret_access_key_secret_name", secret_access_key_secret_name)
        if usage_scopes is not None:
            pulumi.set(__self__, "usage_scopes", usage_scopes)
        if use_ec2_iam_credentials is not None:
            pulumi.set(__self__, "use_ec2_iam_credentials", use_ec2_iam_credentials)
        if use_irsa is not None:
            pulumi.set(__self__, "use_irsa", use_irsa)

    @_builtins.property
    @pulumi.getter(name="accessKeyId")
    def access_key_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The plain text AWS access key id.
        """
        return pulumi.get(self, "access_key_id")

    @access_key_id.setter
    def access_key_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_key_id", value)

    @_builtins.property
    @pulumi.getter(name="accessKeyIdSecretName")
    def access_key_id_secret_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Harness secret containing the AWS access key id
        """
        return pulumi.get(self, "access_key_id_secret_name")

    @access_key_id_secret_name.setter
    def access_key_id_secret_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_key_id_secret_name", value)

    @_builtins.property
    @pulumi.getter(name="assumeCrossAccountRole")
    def assume_cross_account_role(self) -> Optional[pulumi.Input['AwsAssumeCrossAccountRoleArgs']]:
        """
        Configuration for assuming a cross account role.
        """
        return pulumi.get(self, "assume_cross_account_role")

    @assume_cross_account_role.setter
    def assume_cross_account_role(self, value: Optional[pulumi.Input['AwsAssumeCrossAccountRoleArgs']]):
        pulumi.set(self, "assume_cross_account_role", value)

    @_builtins.property
    @pulumi.getter(name="delegateSelector")
    def delegate_selector(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Select the Delegate to use via one of its Selectors.
        """
        return pulumi.get(self, "delegate_selector")

    @delegate_selector.setter
    def delegate_selector(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "delegate_selector", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the cloud provider.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="secretAccessKeySecretName")
    def secret_access_key_secret_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Harness secret containing the AWS secret access key.
        """
        return pulumi.get(self, "secret_access_key_secret_name")

    @secret_access_key_secret_name.setter
    def secret_access_key_secret_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_access_key_secret_name", value)

    @_builtins.property
    @pulumi.getter(name="usageScopes")
    def usage_scopes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AwsUsageScopeArgs']]]]:
        """
        This block is used for scoping the resource to a specific set of applications or environments.
        """
        return pulumi.get(self, "usage_scopes")

    @usage_scopes.setter
    def usage_scopes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AwsUsageScopeArgs']]]]):
        pulumi.set(self, "usage_scopes", value)

    @_builtins.property
    @pulumi.getter(name="useEc2IamCredentials")
    def use_ec2_iam_credentials(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Use the EC2 Instance Profile for Service Accounts.
        """
        return pulumi.get(self, "use_ec2_iam_credentials")

    @use_ec2_iam_credentials.setter
    def use_ec2_iam_credentials(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "use_ec2_iam_credentials", value)

    @_builtins.property
    @pulumi.getter(name="useIrsa")
    def use_irsa(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Use the AWS IAM Role for Service Accounts.
        """
        return pulumi.get(self, "use_irsa")

    @use_irsa.setter
    def use_irsa(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "use_irsa", value)


@pulumi.type_token("harness:cloudprovider/aws:Aws")
class Aws(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_key_id: Optional[pulumi.Input[_builtins.str]] = None,
                 access_key_id_secret_name: Optional[pulumi.Input[_builtins.str]] = None,
                 assume_cross_account_role: Optional[pulumi.Input[Union['AwsAssumeCrossAccountRoleArgs', 'AwsAssumeCrossAccountRoleArgsDict']]] = None,
                 delegate_selector: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_access_key_secret_name: Optional[pulumi.Input[_builtins.str]] = None,
                 usage_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AwsUsageScopeArgs', 'AwsUsageScopeArgsDict']]]]] = None,
                 use_ec2_iam_credentials: Optional[pulumi.Input[_builtins.bool]] = None,
                 use_irsa: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        Resource for creating an AWS cloud provider. This resource uses the config-as-code API's. When updating the `name` or `path` of this resource you should typically also set the `create_before_destroy = true` lifecycle setting.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        default = harness.get_secret_manager(default=True)
        aws_access_key = harness.EncryptedText("aws_access_key",
            name="aws_access_key",
            value="<ACCESS_KEY_ID>",
            secret_manager_id=default.id)
        aws_secret_key = harness.EncryptedText("aws_secret_key",
            name="aws_secret_key",
            value="<SECRET_KEY_ID>",
            secret_manager_id=default.id)
        aws = harness.cloudprovider.Aws("aws",
            name="Example aws cloud provider",
            access_key_id_secret_name=aws_access_key.name,
            secret_access_key_secret_name=aws_secret_key.name)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the Harness aws cloud provider id.

        ```sh
        $ pulumi import harness:cloudprovider/aws:Aws example <provider_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_key_id: The plain text AWS access key id.
        :param pulumi.Input[_builtins.str] access_key_id_secret_name: The name of the Harness secret containing the AWS access key id
        :param pulumi.Input[Union['AwsAssumeCrossAccountRoleArgs', 'AwsAssumeCrossAccountRoleArgsDict']] assume_cross_account_role: Configuration for assuming a cross account role.
        :param pulumi.Input[_builtins.str] delegate_selector: Select the Delegate to use via one of its Selectors.
        :param pulumi.Input[_builtins.str] name: The name of the cloud provider.
        :param pulumi.Input[_builtins.str] secret_access_key_secret_name: The name of the Harness secret containing the AWS secret access key.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AwsUsageScopeArgs', 'AwsUsageScopeArgsDict']]]] usage_scopes: This block is used for scoping the resource to a specific set of applications or environments.
        :param pulumi.Input[_builtins.bool] use_ec2_iam_credentials: Use the EC2 Instance Profile for Service Accounts.
        :param pulumi.Input[_builtins.bool] use_irsa: Use the AWS IAM Role for Service Accounts.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AwsArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating an AWS cloud provider. This resource uses the config-as-code API's. When updating the `name` or `path` of this resource you should typically also set the `create_before_destroy = true` lifecycle setting.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        default = harness.get_secret_manager(default=True)
        aws_access_key = harness.EncryptedText("aws_access_key",
            name="aws_access_key",
            value="<ACCESS_KEY_ID>",
            secret_manager_id=default.id)
        aws_secret_key = harness.EncryptedText("aws_secret_key",
            name="aws_secret_key",
            value="<SECRET_KEY_ID>",
            secret_manager_id=default.id)
        aws = harness.cloudprovider.Aws("aws",
            name="Example aws cloud provider",
            access_key_id_secret_name=aws_access_key.name,
            secret_access_key_secret_name=aws_secret_key.name)
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the Harness aws cloud provider id.

        ```sh
        $ pulumi import harness:cloudprovider/aws:Aws example <provider_id>
        ```

        :param str resource_name: The name of the resource.
        :param AwsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AwsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_key_id: Optional[pulumi.Input[_builtins.str]] = None,
                 access_key_id_secret_name: Optional[pulumi.Input[_builtins.str]] = None,
                 assume_cross_account_role: Optional[pulumi.Input[Union['AwsAssumeCrossAccountRoleArgs', 'AwsAssumeCrossAccountRoleArgsDict']]] = None,
                 delegate_selector: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_access_key_secret_name: Optional[pulumi.Input[_builtins.str]] = None,
                 usage_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AwsUsageScopeArgs', 'AwsUsageScopeArgsDict']]]]] = None,
                 use_ec2_iam_credentials: Optional[pulumi.Input[_builtins.bool]] = None,
                 use_irsa: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AwsArgs.__new__(AwsArgs)

            __props__.__dict__["access_key_id"] = access_key_id
            __props__.__dict__["access_key_id_secret_name"] = access_key_id_secret_name
            __props__.__dict__["assume_cross_account_role"] = assume_cross_account_role
            __props__.__dict__["delegate_selector"] = delegate_selector
            __props__.__dict__["name"] = name
            __props__.__dict__["secret_access_key_secret_name"] = secret_access_key_secret_name
            __props__.__dict__["usage_scopes"] = usage_scopes
            __props__.__dict__["use_ec2_iam_credentials"] = use_ec2_iam_credentials
            __props__.__dict__["use_irsa"] = use_irsa
        super(Aws, __self__).__init__(
            'harness:cloudprovider/aws:Aws',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_key_id: Optional[pulumi.Input[_builtins.str]] = None,
            access_key_id_secret_name: Optional[pulumi.Input[_builtins.str]] = None,
            assume_cross_account_role: Optional[pulumi.Input[Union['AwsAssumeCrossAccountRoleArgs', 'AwsAssumeCrossAccountRoleArgsDict']]] = None,
            delegate_selector: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            secret_access_key_secret_name: Optional[pulumi.Input[_builtins.str]] = None,
            usage_scopes: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AwsUsageScopeArgs', 'AwsUsageScopeArgsDict']]]]] = None,
            use_ec2_iam_credentials: Optional[pulumi.Input[_builtins.bool]] = None,
            use_irsa: Optional[pulumi.Input[_builtins.bool]] = None) -> 'Aws':
        """
        Get an existing Aws resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_key_id: The plain text AWS access key id.
        :param pulumi.Input[_builtins.str] access_key_id_secret_name: The name of the Harness secret containing the AWS access key id
        :param pulumi.Input[Union['AwsAssumeCrossAccountRoleArgs', 'AwsAssumeCrossAccountRoleArgsDict']] assume_cross_account_role: Configuration for assuming a cross account role.
        :param pulumi.Input[_builtins.str] delegate_selector: Select the Delegate to use via one of its Selectors.
        :param pulumi.Input[_builtins.str] name: The name of the cloud provider.
        :param pulumi.Input[_builtins.str] secret_access_key_secret_name: The name of the Harness secret containing the AWS secret access key.
        :param pulumi.Input[Sequence[pulumi.Input[Union['AwsUsageScopeArgs', 'AwsUsageScopeArgsDict']]]] usage_scopes: This block is used for scoping the resource to a specific set of applications or environments.
        :param pulumi.Input[_builtins.bool] use_ec2_iam_credentials: Use the EC2 Instance Profile for Service Accounts.
        :param pulumi.Input[_builtins.bool] use_irsa: Use the AWS IAM Role for Service Accounts.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AwsState.__new__(_AwsState)

        __props__.__dict__["access_key_id"] = access_key_id
        __props__.__dict__["access_key_id_secret_name"] = access_key_id_secret_name
        __props__.__dict__["assume_cross_account_role"] = assume_cross_account_role
        __props__.__dict__["delegate_selector"] = delegate_selector
        __props__.__dict__["name"] = name
        __props__.__dict__["secret_access_key_secret_name"] = secret_access_key_secret_name
        __props__.__dict__["usage_scopes"] = usage_scopes
        __props__.__dict__["use_ec2_iam_credentials"] = use_ec2_iam_credentials
        __props__.__dict__["use_irsa"] = use_irsa
        return Aws(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accessKeyId")
    def access_key_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The plain text AWS access key id.
        """
        return pulumi.get(self, "access_key_id")

    @_builtins.property
    @pulumi.getter(name="accessKeyIdSecretName")
    def access_key_id_secret_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The name of the Harness secret containing the AWS access key id
        """
        return pulumi.get(self, "access_key_id_secret_name")

    @_builtins.property
    @pulumi.getter(name="assumeCrossAccountRole")
    def assume_cross_account_role(self) -> pulumi.Output[Optional['outputs.AwsAssumeCrossAccountRole']]:
        """
        Configuration for assuming a cross account role.
        """
        return pulumi.get(self, "assume_cross_account_role")

    @_builtins.property
    @pulumi.getter(name="delegateSelector")
    def delegate_selector(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Select the Delegate to use via one of its Selectors.
        """
        return pulumi.get(self, "delegate_selector")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the cloud provider.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="secretAccessKeySecretName")
    def secret_access_key_secret_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The name of the Harness secret containing the AWS secret access key.
        """
        return pulumi.get(self, "secret_access_key_secret_name")

    @_builtins.property
    @pulumi.getter(name="usageScopes")
    def usage_scopes(self) -> pulumi.Output[Optional[Sequence['outputs.AwsUsageScope']]]:
        """
        This block is used for scoping the resource to a specific set of applications or environments.
        """
        return pulumi.get(self, "usage_scopes")

    @_builtins.property
    @pulumi.getter(name="useEc2IamCredentials")
    def use_ec2_iam_credentials(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Use the EC2 Instance Profile for Service Accounts.
        """
        return pulumi.get(self, "use_ec2_iam_credentials")

    @_builtins.property
    @pulumi.getter(name="useIrsa")
    def use_irsa(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Use the AWS IAM Role for Service Accounts.
        """
        return pulumi.get(self, "use_irsa")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetConnectorCustomhealthsourceResult',
    'AwaitableGetConnectorCustomhealthsourceResult',
    'get_connector_customhealthsource',
    'get_connector_customhealthsource_output',
]

@pulumi.output_type
class GetConnectorCustomhealthsourceResult:
    """
    A collection of values returned by getConnectorCustomhealthsource.
    """
    def __init__(__self__, delegate_selectors=None, description=None, headers=None, id=None, identifier=None, method=None, name=None, org_id=None, params=None, project_id=None, tags=None, url=None, validation_body=None, validation_path=None):
        if delegate_selectors and not isinstance(delegate_selectors, list):
            raise TypeError("Expected argument 'delegate_selectors' to be a list")
        pulumi.set(__self__, "delegate_selectors", delegate_selectors)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if headers and not isinstance(headers, list):
            raise TypeError("Expected argument 'headers' to be a list")
        pulumi.set(__self__, "headers", headers)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if method and not isinstance(method, str):
            raise TypeError("Expected argument 'method' to be a str")
        pulumi.set(__self__, "method", method)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if params and not isinstance(params, list):
            raise TypeError("Expected argument 'params' to be a list")
        pulumi.set(__self__, "params", params)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if url and not isinstance(url, str):
            raise TypeError("Expected argument 'url' to be a str")
        pulumi.set(__self__, "url", url)
        if validation_body and not isinstance(validation_body, str):
            raise TypeError("Expected argument 'validation_body' to be a str")
        pulumi.set(__self__, "validation_body", validation_body)
        if validation_path and not isinstance(validation_path, str):
            raise TypeError("Expected argument 'validation_path' to be a str")
        pulumi.set(__self__, "validation_path", validation_path)

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> Sequence[_builtins.str]:
        """
        Tags to filter delegates for connection.
        """
        return pulumi.get(self, "delegate_selectors")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def headers(self) -> Sequence['outputs.GetConnectorCustomhealthsourceHeaderResult']:
        """
        Headers.
        """
        return pulumi.get(self, "headers")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def method(self) -> _builtins.str:
        """
        HTTP Verb Method for the API Call
        """
        return pulumi.get(self, "method")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter
    def params(self) -> Sequence['outputs.GetConnectorCustomhealthsourceParamResult']:
        """
        Parameters.
        """
        return pulumi.get(self, "params")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def url(self) -> _builtins.str:
        """
        URL of the Custom Health source server.
        """
        return pulumi.get(self, "url")

    @_builtins.property
    @pulumi.getter(name="validationBody")
    def validation_body(self) -> _builtins.str:
        """
        Body to be sent with the API Call
        """
        return pulumi.get(self, "validation_body")

    @_builtins.property
    @pulumi.getter(name="validationPath")
    def validation_path(self) -> _builtins.str:
        """
        Path to be added to the base URL for the API Call
        """
        return pulumi.get(self, "validation_path")


class AwaitableGetConnectorCustomhealthsourceResult(GetConnectorCustomhealthsourceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetConnectorCustomhealthsourceResult(
            delegate_selectors=self.delegate_selectors,
            description=self.description,
            headers=self.headers,
            id=self.id,
            identifier=self.identifier,
            method=self.method,
            name=self.name,
            org_id=self.org_id,
            params=self.params,
            project_id=self.project_id,
            tags=self.tags,
            url=self.url,
            validation_body=self.validation_body,
            validation_path=self.validation_path)


def get_connector_customhealthsource(identifier: Optional[_builtins.str] = None,
                                     name: Optional[_builtins.str] = None,
                                     org_id: Optional[_builtins.str] = None,
                                     project_id: Optional[_builtins.str] = None,
                                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetConnectorCustomhealthsourceResult:
    """
    Datasource for looking up a Custom Health source connector.


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getConnectorCustomhealthsource:getConnectorCustomhealthsource', __args__, opts=opts, typ=GetConnectorCustomhealthsourceResult).value

    return AwaitableGetConnectorCustomhealthsourceResult(
        delegate_selectors=pulumi.get(__ret__, 'delegate_selectors'),
        description=pulumi.get(__ret__, 'description'),
        headers=pulumi.get(__ret__, 'headers'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        method=pulumi.get(__ret__, 'method'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        params=pulumi.get(__ret__, 'params'),
        project_id=pulumi.get(__ret__, 'project_id'),
        tags=pulumi.get(__ret__, 'tags'),
        url=pulumi.get(__ret__, 'url'),
        validation_body=pulumi.get(__ret__, 'validation_body'),
        validation_path=pulumi.get(__ret__, 'validation_path'))
def get_connector_customhealthsource_output(identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                            name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                            org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                            project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetConnectorCustomhealthsourceResult]:
    """
    Datasource for looking up a Custom Health source connector.


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getConnectorCustomhealthsource:getConnectorCustomhealthsource', __args__, opts=opts, typ=GetConnectorCustomhealthsourceResult)
    return __ret__.apply(lambda __response__: GetConnectorCustomhealthsourceResult(
        delegate_selectors=pulumi.get(__response__, 'delegate_selectors'),
        description=pulumi.get(__response__, 'description'),
        headers=pulumi.get(__response__, 'headers'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        method=pulumi.get(__response__, 'method'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        params=pulumi.get(__response__, 'params'),
        project_id=pulumi.get(__response__, 'project_id'),
        tags=pulumi.get(__response__, 'tags'),
        url=pulumi.get(__response__, 'url'),
        validation_body=pulumi.get(__response__, 'validation_body'),
        validation_path=pulumi.get(__response__, 'validation_path')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['FiltersArgs', 'Filters']

@pulumi.input_type
class FiltersArgs:
    def __init__(__self__, *,
                 filter_properties: pulumi.Input['FiltersFilterPropertiesArgs'],
                 identifier: pulumi.Input[_builtins.str],
                 type: pulumi.Input[_builtins.str],
                 filter_visibility: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Filters resource.
        :param pulumi.Input['FiltersFilterPropertiesArgs'] filter_properties: Properties of the filter entity defined in Harness.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource
        :param pulumi.Input[_builtins.str] type: Type of filter. Currently supported types are {Connector, DelegateProfile, Delegate, EnvironmentGroup, FileStore, Environment}
        :param pulumi.Input[_builtins.str] filter_visibility: This indicates visibility of filter. By default, everyone can view this filter. Can either be EveryOne or OnlyCreator
        :param pulumi.Input[_builtins.str] name: Name of the Filter
        :param pulumi.Input[_builtins.str] org_id: organization Identifier for the Entity
        :param pulumi.Input[_builtins.str] project_id: project Identifier for the Entity
        """
        pulumi.set(__self__, "filter_properties", filter_properties)
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "type", type)
        if filter_visibility is not None:
            pulumi.set(__self__, "filter_visibility", filter_visibility)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)

    @_builtins.property
    @pulumi.getter(name="filterProperties")
    def filter_properties(self) -> pulumi.Input['FiltersFilterPropertiesArgs']:
        """
        Properties of the filter entity defined in Harness.
        """
        return pulumi.get(self, "filter_properties")

    @filter_properties.setter
    def filter_properties(self, value: pulumi.Input['FiltersFilterPropertiesArgs']):
        pulumi.set(self, "filter_properties", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        Type of filter. Currently supported types are {Connector, DelegateProfile, Delegate, EnvironmentGroup, FileStore, Environment}
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="filterVisibility")
    def filter_visibility(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        This indicates visibility of filter. By default, everyone can view this filter. Can either be EveryOne or OnlyCreator
        """
        return pulumi.get(self, "filter_visibility")

    @filter_visibility.setter
    def filter_visibility(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "filter_visibility", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Filter
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        organization Identifier for the Entity
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        project Identifier for the Entity
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)


@pulumi.input_type
class _FiltersState:
    def __init__(__self__, *,
                 filter_properties: Optional[pulumi.Input['FiltersFilterPropertiesArgs']] = None,
                 filter_visibility: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Filters resources.
        :param pulumi.Input['FiltersFilterPropertiesArgs'] filter_properties: Properties of the filter entity defined in Harness.
        :param pulumi.Input[_builtins.str] filter_visibility: This indicates visibility of filter. By default, everyone can view this filter. Can either be EveryOne or OnlyCreator
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource
        :param pulumi.Input[_builtins.str] name: Name of the Filter
        :param pulumi.Input[_builtins.str] org_id: organization Identifier for the Entity
        :param pulumi.Input[_builtins.str] project_id: project Identifier for the Entity
        :param pulumi.Input[_builtins.str] type: Type of filter. Currently supported types are {Connector, DelegateProfile, Delegate, EnvironmentGroup, FileStore, Environment}
        """
        if filter_properties is not None:
            pulumi.set(__self__, "filter_properties", filter_properties)
        if filter_visibility is not None:
            pulumi.set(__self__, "filter_visibility", filter_visibility)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="filterProperties")
    def filter_properties(self) -> Optional[pulumi.Input['FiltersFilterPropertiesArgs']]:
        """
        Properties of the filter entity defined in Harness.
        """
        return pulumi.get(self, "filter_properties")

    @filter_properties.setter
    def filter_properties(self, value: Optional[pulumi.Input['FiltersFilterPropertiesArgs']]):
        pulumi.set(self, "filter_properties", value)

    @_builtins.property
    @pulumi.getter(name="filterVisibility")
    def filter_visibility(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        This indicates visibility of filter. By default, everyone can view this filter. Can either be EveryOne or OnlyCreator
        """
        return pulumi.get(self, "filter_visibility")

    @filter_visibility.setter
    def filter_visibility(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "filter_visibility", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Filter
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        organization Identifier for the Entity
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        project Identifier for the Entity
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of filter. Currently supported types are {Connector, DelegateProfile, Delegate, EnvironmentGroup, FileStore, Environment}
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("harness:platform/filters:Filters")
class Filters(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 filter_properties: Optional[pulumi.Input[Union['FiltersFilterPropertiesArgs', 'FiltersFilterPropertiesArgsDict']]] = None,
                 filter_visibility: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating a Harness Filter. This resource support filters of types {Connector, DelegateProfile, Delegate, EnvironmentGroup, FileStore, Environment}

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.platform.Filters("test",
            identifier="identifier",
            name="name",
            org_id="org_id",
            project_id="project_id",
            type="Connector",
            filter_properties={
                "tags": ["foo:bar"],
                "filter_type": "Connector",
            },
            filter_visibility="EveryOne")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level filter

        ```sh
        $ pulumi import harness:platform/filters:Filters example <filter_id>/<type>
        ```

        Import org level filter

        ```sh
        $ pulumi import harness:platform/filters:Filters example <ord_id>/<filter_id>/<type>
        ```

        Import project level filter

        ```sh
        $ pulumi import harness:platform/filters:Filters example <org_id>/<project_id>/<filter_id>/<type>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['FiltersFilterPropertiesArgs', 'FiltersFilterPropertiesArgsDict']] filter_properties: Properties of the filter entity defined in Harness.
        :param pulumi.Input[_builtins.str] filter_visibility: This indicates visibility of filter. By default, everyone can view this filter. Can either be EveryOne or OnlyCreator
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource
        :param pulumi.Input[_builtins.str] name: Name of the Filter
        :param pulumi.Input[_builtins.str] org_id: organization Identifier for the Entity
        :param pulumi.Input[_builtins.str] project_id: project Identifier for the Entity
        :param pulumi.Input[_builtins.str] type: Type of filter. Currently supported types are {Connector, DelegateProfile, Delegate, EnvironmentGroup, FileStore, Environment}
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FiltersArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Harness Filter. This resource support filters of types {Connector, DelegateProfile, Delegate, EnvironmentGroup, FileStore, Environment}

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        test = harness.platform.Filters("test",
            identifier="identifier",
            name="name",
            org_id="org_id",
            project_id="project_id",
            type="Connector",
            filter_properties={
                "tags": ["foo:bar"],
                "filter_type": "Connector",
            },
            filter_visibility="EveryOne")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level filter

        ```sh
        $ pulumi import harness:platform/filters:Filters example <filter_id>/<type>
        ```

        Import org level filter

        ```sh
        $ pulumi import harness:platform/filters:Filters example <ord_id>/<filter_id>/<type>
        ```

        Import project level filter

        ```sh
        $ pulumi import harness:platform/filters:Filters example <org_id>/<project_id>/<filter_id>/<type>
        ```

        :param str resource_name: The name of the resource.
        :param FiltersArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FiltersArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 filter_properties: Optional[pulumi.Input[Union['FiltersFilterPropertiesArgs', 'FiltersFilterPropertiesArgsDict']]] = None,
                 filter_visibility: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FiltersArgs.__new__(FiltersArgs)

            if filter_properties is None and not opts.urn:
                raise TypeError("Missing required property 'filter_properties'")
            __props__.__dict__["filter_properties"] = filter_properties
            __props__.__dict__["filter_visibility"] = filter_visibility
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["name"] = name
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
        super(Filters, __self__).__init__(
            'harness:platform/filters:Filters',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            filter_properties: Optional[pulumi.Input[Union['FiltersFilterPropertiesArgs', 'FiltersFilterPropertiesArgsDict']]] = None,
            filter_visibility: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'Filters':
        """
        Get an existing Filters resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['FiltersFilterPropertiesArgs', 'FiltersFilterPropertiesArgsDict']] filter_properties: Properties of the filter entity defined in Harness.
        :param pulumi.Input[_builtins.str] filter_visibility: This indicates visibility of filter. By default, everyone can view this filter. Can either be EveryOne or OnlyCreator
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource
        :param pulumi.Input[_builtins.str] name: Name of the Filter
        :param pulumi.Input[_builtins.str] org_id: organization Identifier for the Entity
        :param pulumi.Input[_builtins.str] project_id: project Identifier for the Entity
        :param pulumi.Input[_builtins.str] type: Type of filter. Currently supported types are {Connector, DelegateProfile, Delegate, EnvironmentGroup, FileStore, Environment}
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FiltersState.__new__(_FiltersState)

        __props__.__dict__["filter_properties"] = filter_properties
        __props__.__dict__["filter_visibility"] = filter_visibility
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["type"] = type
        return Filters(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="filterProperties")
    def filter_properties(self) -> pulumi.Output['outputs.FiltersFilterProperties']:
        """
        Properties of the filter entity defined in Harness.
        """
        return pulumi.get(self, "filter_properties")

    @_builtins.property
    @pulumi.getter(name="filterVisibility")
    def filter_visibility(self) -> pulumi.Output[_builtins.str]:
        """
        This indicates visibility of filter. By default, everyone can view this filter. Can either be EveryOne or OnlyCreator
        """
        return pulumi.get(self, "filter_visibility")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the Filter
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        organization Identifier for the Entity
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        project Identifier for the Entity
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        Type of filter. Currently supported types are {Connector, DelegateProfile, Delegate, EnvironmentGroup, FileStore, Environment}
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetGitopsAppProjectResult',
    'AwaitableGetGitopsAppProjectResult',
    'get_gitops_app_project',
    'get_gitops_app_project_output',
]

@pulumi.output_type
class GetGitopsAppProjectResult:
    """
    A collection of values returned by getGitopsAppProject.
    """
    def __init__(__self__, account_id=None, agent_id=None, id=None, org_id=None, project_id=None, query_name=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if agent_id and not isinstance(agent_id, str):
            raise TypeError("Expected argument 'agent_id' to be a str")
        pulumi.set(__self__, "agent_id", agent_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if query_name and not isinstance(query_name, str):
            raise TypeError("Expected argument 'query_name' to be a str")
        pulumi.set(__self__, "query_name", query_name)

    @_builtins.property
    @pulumi.getter(name="accountId")
    @_utilities.deprecated("""This field is deprecated and will be removed in a future release.""")
    def account_id(self) -> _builtins.str:
        """
        Account identifier of the GitOps Agent where argo project resides.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="agentId")
    def agent_id(self) -> _builtins.str:
        """
        Agent identifier of the agent where argo project resides(include scope prefix)
        """
        return pulumi.get(self, "agent_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Org identifier of the GitOps Agent where argo project resides.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Project identifier of the Gitops Agent where argo project resides.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="queryName")
    def query_name(self) -> _builtins.str:
        """
        Identifier for the GitOps Argo project.
        """
        return pulumi.get(self, "query_name")


class AwaitableGetGitopsAppProjectResult(GetGitopsAppProjectResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGitopsAppProjectResult(
            account_id=self.account_id,
            agent_id=self.agent_id,
            id=self.id,
            org_id=self.org_id,
            project_id=self.project_id,
            query_name=self.query_name)


def get_gitops_app_project(account_id: Optional[_builtins.str] = None,
                           agent_id: Optional[_builtins.str] = None,
                           org_id: Optional[_builtins.str] = None,
                           project_id: Optional[_builtins.str] = None,
                           query_name: Optional[_builtins.str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGitopsAppProjectResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_gitops_app_project(agent_id="agent_id",
        query_name="query_name")
    ```


    :param _builtins.str account_id: Account identifier of the GitOps Agent where argo project resides.
    :param _builtins.str agent_id: Agent identifier of the agent where argo project resides(include scope prefix)
    :param _builtins.str org_id: Org identifier of the GitOps Agent where argo project resides.
    :param _builtins.str project_id: Project identifier of the Gitops Agent where argo project resides.
    :param _builtins.str query_name: Identifier for the GitOps Argo project.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['agentId'] = agent_id
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['queryName'] = query_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getGitopsAppProject:getGitopsAppProject', __args__, opts=opts, typ=GetGitopsAppProjectResult).value

    return AwaitableGetGitopsAppProjectResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        agent_id=pulumi.get(__ret__, 'agent_id'),
        id=pulumi.get(__ret__, 'id'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        query_name=pulumi.get(__ret__, 'query_name'))
def get_gitops_app_project_output(account_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                  agent_id: Optional[pulumi.Input[_builtins.str]] = None,
                                  org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                  project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                  query_name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetGitopsAppProjectResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_gitops_app_project(agent_id="agent_id",
        query_name="query_name")
    ```


    :param _builtins.str account_id: Account identifier of the GitOps Agent where argo project resides.
    :param _builtins.str agent_id: Agent identifier of the agent where argo project resides(include scope prefix)
    :param _builtins.str org_id: Org identifier of the GitOps Agent where argo project resides.
    :param _builtins.str project_id: Project identifier of the Gitops Agent where argo project resides.
    :param _builtins.str query_name: Identifier for the GitOps Argo project.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['agentId'] = agent_id
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['queryName'] = query_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getGitopsAppProject:getGitopsAppProject', __args__, opts=opts, typ=GetGitopsAppProjectResult)
    return __ret__.apply(lambda __response__: GetGitopsAppProjectResult(
        account_id=pulumi.get(__response__, 'account_id'),
        agent_id=pulumi.get(__response__, 'agent_id'),
        id=pulumi.get(__response__, 'id'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        query_name=pulumi.get(__response__, 'query_name')))
